# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_anda_global_optspecs
	string join \n c/config= v/verbose q/quiet t/target-dir= h/help V/version
end

function __fish_anda_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_anda_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_anda_using_subcommand
	set -l cmd (__fish_anda_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c anda -n "__fish_anda_needs_command" -s c -l config -d 'Path to Andaman configuration file' -r -F
complete -c anda -n "__fish_anda_needs_command" -s t -l target-dir -d 'Output directory for built packages' -r -F
complete -c anda -n "__fish_anda_needs_command" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_needs_command" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c anda -n "__fish_anda_needs_command" -s V -l version -d 'Print version'
complete -c anda -n "__fish_anda_needs_command" -f -a "build" -d 'Build a project'
complete -c anda -n "__fish_anda_needs_command" -f -a "clean" -d 'Cleans up the build directory'
complete -c anda -n "__fish_anda_needs_command" -f -a "list" -d 'Lists all projects in the manifest'
complete -c anda -n "__fish_anda_needs_command" -f -a "init" -d 'Initializes a new project manifest'
complete -c anda -n "__fish_anda_needs_command" -f -a "completion" -d 'Generate shell completions'
complete -c anda -n "__fish_anda_needs_command" -f -a "ci" -d 'Get CI output for Github Actions'
complete -c anda -n "__fish_anda_needs_command" -f -a "update" -d 'Update all projects'
complete -c anda -n "__fish_anda_needs_command" -f -a "run" -d 'Run .rhai scripts'
complete -c anda -n "__fish_anda_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c anda -n "__fish_anda_using_subcommand build" -s p -l package -d 'Builds a specific artifact format' -r -f -a "rpm\t''
docker\t''
podman\t''
flatpak\t''
all\t''"
complete -c anda -n "__fish_anda_using_subcommand build" -s r -l rpm-builder -d 'RPM: Builder backend' -r -f -a "mock\t''
rpmbuild\t''"
complete -c anda -n "__fish_anda_using_subcommand build" -s D -l rpm-macro -d 'RPM: Define a custom macro can be defined multiple times' -r
complete -c anda -n "__fish_anda_using_subcommand build" -l rpm-target -d 'RPM: A target to pass to rpmbuild/mock, useful for cross compilation' -r
complete -c anda -n "__fish_anda_using_subcommand build" -s c -l mock-config -d 'RPM: Mock configuration' -r
complete -c anda -n "__fish_anda_using_subcommand build" -s R -l extra-repos -d 'RPM: Extra repositories to pass to mock' -r
complete -c anda -n "__fish_anda_using_subcommand build" -l extra-sources -d 'Flatpak: Extra source directory can be defined multiple times' -r
complete -c anda -n "__fish_anda_using_subcommand build" -l extra-sources-url -d 'Flatpak: Extra source URL can be defined multiple times' -r
complete -c anda -n "__fish_anda_using_subcommand build" -l label -d 'OCI: Labels to add to the image' -r
complete -c anda -n "__fish_anda_using_subcommand build" -l build-arg -d 'OCI: Build Arguments to pass to the build' -r
complete -c anda -n "__fish_anda_using_subcommand build" -s a -l all -d 'Builds all projects in the current directory'
complete -c anda -n "__fish_anda_using_subcommand build" -l no-mirrors -d 'RPM: Do not mirror repositories'
complete -c anda -n "__fish_anda_using_subcommand build" -l dont-delete-build-dir -d 'Flatpak: Do not delete the build directory'
complete -c anda -n "__fish_anda_using_subcommand build" -l compress -d 'OCI: compress the context with gzip'
complete -c anda -n "__fish_anda_using_subcommand build" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand build" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand build" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c anda -n "__fish_anda_using_subcommand clean" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand clean" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand clean" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand list" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand list" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand list" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand init" -s y -l yes -d 'Assume yes to all questions'
complete -c anda -n "__fish_anda_using_subcommand init" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand init" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand init" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand completion" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand completion" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand completion" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand ci" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand ci" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand ci" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand update" -s l -l labels -d 'Labels to pass to the scripts' -r
complete -c anda -n "__fish_anda_using_subcommand update" -s f -l filters -d 'Only run update scripts in project with the specified labels' -r
complete -c anda -n "__fish_anda_using_subcommand update" -s e -l excludes -d 'Exclude update scripts in project with the specified labels' -r
complete -c anda -n "__fish_anda_using_subcommand update" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand update" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand update" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c anda -n "__fish_anda_using_subcommand run" -s l -l labels -r
complete -c anda -n "__fish_anda_using_subcommand run" -s v -l verbose -d 'Increase logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand run" -s q -l quiet -d 'Decrease logging verbosity'
complete -c anda -n "__fish_anda_using_subcommand run" -s h -l help -d 'Print help'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "build" -d 'Build a project'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "clean" -d 'Cleans up the build directory'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "list" -d 'Lists all projects in the manifest'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "init" -d 'Initializes a new project manifest'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "completion" -d 'Generate shell completions'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "ci" -d 'Get CI output for Github Actions'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "update" -d 'Update all projects'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "run" -d 'Run .rhai scripts'
complete -c anda -n "__fish_anda_using_subcommand help; and not __fish_seen_subcommand_from build clean list init completion ci update run help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
